@@ -85,7 +85,7 @@ sub AUTOLOAD {
 # tie returns the object, so the value returned to require will be true.
 tie %Config, 'Config', {
     archlibexp => '/usr/lib/perl5/5.26/core_perl',
-    archname => 'armv5tel-linux-thread-multi',
+    archname => 'armv7l-linux-thread-multi',
     cc => 'cc',
     d_readlink => 'define',
     d_symlink => 'define',
@@ -96,9 +96,9 @@ tie %Config, 'Config', {
     inc_version_list => ' ',
     intsize => '4',
     ldlibpthname => 'LD_LIBRARY_PATH',
-    libpth => '/usr/local/lib /usr/lib/gcc/armv5tel-unknown-linux-gnueabi/7.2.0/include-fixed /usr/lib /lib',
+    libpth => '/usr/local/lib /usr/lib/gcc/armv5tel-unknown-linux-gnueabi/7.2.1/include-fixed /usr/lib /lib',
     osname => 'linux',
-    osvers => '4.9.50-3-arch',
+    osvers => '4.14.13-1-arch',
     path_sep => ':',
     privlibexp => '/usr/share/perl5/core_perl',
     scriptdir => '/usr/bin/core_perl',
